import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import 'vscode/vscode/vs/platform/actions/common/actions';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import './localizationsActions.js';
import { Extensions } from 'vscode/vscode/vs/workbench/services/extensionManagement/common/extensionFeatures';
import 'vscode/vscode/vs/workbench/services/extensions/common/extensionsRegistry';

class LocalizationsDataRenderer extends Disposable {
    constructor() {
        super(...arguments);
        this.type = 'table';
    }
    shouldRender(manifest) {
        return !!manifest.contributes?.localizations;
    }
    render(manifest) {
        const localizations = manifest.contributes?.localizations || [];
        if (!localizations.length) {
            return { data: { headers: [], rows: [] }, dispose: () => { } };
        }
        const headers = [
            ( localizeWithPath(
                'vs/workbench/contrib/localization/common/localization.contribution',
                'language id',
                "Language ID"
            )),
            ( localizeWithPath(
                'vs/workbench/contrib/localization/common/localization.contribution',
                'localizations language name',
                "Language Name"
            )),
            ( localizeWithPath(
                'vs/workbench/contrib/localization/common/localization.contribution',
                'localizations localized language name',
                "Language Name (Localized)"
            )),
        ];
        const rows = ( localizations
            .sort((a, b) => a.languageId.localeCompare(b.languageId))
            .map(localization => {
            return [
                localization.languageId,
                localization.languageName ?? '',
                localization.localizedLanguageName ?? ''
            ];
        }));
        return {
            data: {
                headers,
                rows
            },
            dispose: () => { }
        };
    }
}
( Registry.as(Extensions.ExtensionFeaturesRegistry)).registerExtensionFeature({
    id: 'localizations',
    label: ( localizeWithPath(
        'vs/workbench/contrib/localization/common/localization.contribution',
        'localizations',
        "Langauage Packs"
    )),
    access: {
        canToggle: false
    },
    renderer: ( new SyncDescriptor(LocalizationsDataRenderer)),
});
